@@ -19,40 +19,135 @@ DecoratedClient::DecoratedClient(Decoration *parent, DecorationBridge *bridge)
 
 DecoratedClient::~DecoratedClient() = default;
 
-#define DELEGATE(type, method)                                                                                                                                 \
-    type DecoratedClient::method() const                                                                                                                       \
-    {                                                                                                                                                          \
-        return d->method();                                                                                                                                    \
-    }
+bool DecoratedClient::isActive() const
+{
+    return d->isActive();
+}
 
-DELEGATE(bool, isActive)
-DELEGATE(QString, caption)
-DELEGATE(bool, isOnAllDesktops)
-DELEGATE(bool, isShaded)
-DELEGATE(QIcon, icon)
-DELEGATE(bool, isMaximized)
-DELEGATE(bool, isMaximizedHorizontally)
-DELEGATE(bool, isMaximizedVertically)
-DELEGATE(bool, isKeepAbove)
-DELEGATE(bool, isKeepBelow)
-DELEGATE(bool, isCloseable)
-DELEGATE(bool, isMaximizeable)
-DELEGATE(bool, isMinimizeable)
-DELEGATE(bool, providesContextHelp)
-DELEGATE(bool, isModal)
-DELEGATE(bool, isShadeable)
-DELEGATE(bool, isMoveable)
-DELEGATE(bool, isResizeable)
-DELEGATE(WId, windowId)
-DELEGATE(WId, decorationId)
-DELEGATE(int, width)
-DELEGATE(int, height)
-DELEGATE(QSize, size)
-DELEGATE(QPalette, palette)
-DELEGATE(Qt::Edges, adjacentScreenEdges)
-DELEGATE(QString, windowClass)
+QString DecoratedClient::caption() const
+{
+    return d->caption();
+}
 
-#undef DELEGATE
+bool DecoratedClient::isOnAllDesktops() const
+{
+    return d->isOnAllDesktops();
+}
+
+bool DecoratedClient::isShaded() const
+{
+    return d->isShaded();
+}
+
+QIcon DecoratedClient::icon() const
+{
+    return d->icon();
+}
+
+bool DecoratedClient::isMaximized() const
+{
+    return d->isMaximized();
+}
+
+bool DecoratedClient::isMaximizedHorizontally() const
+{
+    return d->isMaximizedHorizontally();
+}
+
+bool DecoratedClient::isMaximizedVertically() const
+{
+    return d->isMaximizedVertically();
+}
+
+bool DecoratedClient::isKeepAbove() const
+{
+    return d->isKeepAbove();
+}
+
+bool DecoratedClient::isKeepBelow() const
+{
+    return d->isKeepBelow();
+}
+
+bool DecoratedClient::isCloseable() const
+{
+    return d->isCloseable();
+}
+
+bool DecoratedClient::isMaximizeable() const
+{
+    return d->isMaximizeable();
+}
+
+bool DecoratedClient::isMinimizeable() const
+{
+    return d->isMinimizeable();
+}
+
+bool DecoratedClient::providesContextHelp() const
+{
+    return d->providesContextHelp();
+}
+
+bool DecoratedClient::isModal() const
+{
+    return d->isModal();
+}
+
+bool DecoratedClient::isShadeable() const
+{
+    return d->isShadeable();
+}
+
+bool DecoratedClient::isMoveable() const
+{
+    return d->isMoveable();
+}
+
+bool DecoratedClient::isResizeable() const
+{
+    return d->isResizeable();
+}
+
+WId DecoratedClient::windowId() const
+{
+    return d->windowId();
+}
+
+WId DecoratedClient::decorationId() const
+{
+    return d->decorationId();
+}
+
+int DecoratedClient::width() const
+{
+    return d->width();
+}
+
+int DecoratedClient::height() const
+{
+    return d->height();
+}
+
+QSize DecoratedClient::size() const
+{
+    return d->size();
+}
+
+QPalette DecoratedClient::palette() const
+{
+    return d->palette();
+}
+
+Qt::Edges DecoratedClient::adjacentScreenEdges() const
+{
+    return d->adjacentScreenEdges();
+}
+
+QString DecoratedClient::windowClass() const
+{
+    return d->windowClass();
+}
 
 bool DecoratedClient::hasApplicationMenu() const
 {
